import { defineConfig } from "astro/config";
import mdx from "@astrojs/mdx";
import nodejs from "@astrojs/node";
import { remarkReadingTime } from "./remark-reading-time.mjs";
import { modifiedTime } from "./remark-modified-time.mjs";
import remarkCallout from "@r4ai/remark-callout";

export default defineConfig({
  site: "https://argentumcation.com",
  markdown: {
    syntaxHighlight: false,
    shikiConfig: {
      theme: "css-variables",
    },
    remarkPlugins: [remarkReadingTime, modifiedTime, remarkCallout],
  },
  adapter: nodejs({
    mode: "standalone",
  }),
  output: "hybrid",
  vite: {
    build: {
      rollupOptions: {
        output: {
          manualChunks(id) {
            if (id.includes("node_modules")) {
              return id
                .toString()
                .split("node_modules/")[1]
                .split("/")[0]
                .toString();
            }
          },
        },
      },
    },
  },
  integrations: [
    mdx({
      // Markdown config now ignored
      extendMarkdownConfig: true,
      // No `remarkPlugins` applied
    }),
  ],
});
